Index: content/browser/memory/memory_message_filter.h |
diff --git a/content/browser/memory/memory_message_filter.h b/content/browser/memory/memory_message_filter.h |
index ad13662477e7b64483c760dab093e71e50995982..5241b9cc55624deff047aadfca75bb60d4a05d96 100644 |
--- a/content/browser/memory/memory_message_filter.h |
+++ b/content/browser/memory/memory_message_filter.h |
@@ -36,7 +36,7 @@ class CONTENT_EXPORT MemoryMessageFilter : public BrowserMessageFilter { |
base::MemoryPressureListener::MemoryPressureLevel level); |
protected: |
- friend class MemoryPressureController; |
+ friend class MemoryPressureControllerImpl; |
~MemoryMessageFilter() override; |
@@ -46,7 +46,7 @@ class CONTENT_EXPORT MemoryMessageFilter : public BrowserMessageFilter { |
private: |
// The untyped process host and ProcessType associated with this filter |
// instance. The process host is stored as untyped because it is only used as |
// a key in MemoryPressureController; at no point is it ever deferenced to |
// invoke any members on a process host. |
const void* process_host_; |
ProcessType process_type_; |
@@ -46,7 +46,7 @@ class CONTENT_EXPORT MemoryMessageFilter : public BrowserMessageFilter { |
// The untyped process host and ProcessType associated with this filter |
// instance. The process host is stored as untyped because it is only used as |
- // a key in MemoryPressureController; at no point is it ever deferenced to |
+ // a key in MemoryPressureControllerImpl; at no point is it ever deferenced to |
// invoke any members on a process host. |
const void* process_host_; |